@@ -7,22 +7,25 @@ from .assets import (
     SubdomainsAssets,
     WebEntitiesAssets,
 )
+from .beta import Beta
 from .client import AsmClient
 from .clouds import Clouds
-from .events import Events
 from .inventory import InventorySearch
+from .logbook import Events, Logbook
 from .risks import Risks
 from .seeds import Seeds
 
 __all__ = [
     "AsmClient",
     "Assets",
+    "Beta",
     "CertificatesAssets",
     "Clouds",
     "DomainsAssets",
     "Events",
     "HostsAssets",
     "InventorySearch",
+    "Logbook",
     "Risks",
     "Seeds",
     "SubdomainsAssets",
